# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/loadtesting/agent/v1/agent_registration_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/loadtesting/agent/v1/agent_registration_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nByandex/cloud/loadtesting/agent/v1/agent_registration_service.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\"E\n\x0fRegisterRequest\x12\x1b\n\x13\x63ompute_instance_id\x18\x01 \x01(\t\x12\x15\n\ragent_version\x18\x02 \x01(\t\"-\n\x10RegisterResponse\x12\x19\n\x11\x61gent_instance_id\x18\x01 \x01(\t\"\xbd\x02\n\x1c\x45xternalAgentRegisterRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x1b\n\x13\x63ompute_instance_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x15\n\ragent_version\x18\x04 \x01(\t\x12\x98\x01\n\x06labels\x18\x05 \x03(\x0b\x32K.yandex.cloud.loadtesting.agent.v1.ExternalAgentRegisterRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n\x1d\x45xternalAgentRegisterMetadata\x12\x19\n\x11\x61gent_instance_id\x18\x01 \x01(\t2\xb2\x03\n\x18\x41gentRegistrationService\x12\xa5\x01\n\x08Register\x12\x32.yandex.cloud.loadtesting.agent.v1.RegisterRequest\x1a\x33.yandex.cloud.loadtesting.agent.v1.RegisterResponse\"0\x82\xd3\xe4\x93\x02*\"%/loadtesting/agent/v1/agents/register:\x01*\x12\xed\x01\n\x15\x45xternalAgentRegister\x12?.yandex.cloud.loadtesting.agent.v1.ExternalAgentRegisterRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*.\n\x1d\x45xternalAgentRegisterMetadata\x12\rAgentInstance\x82\xd3\xe4\x93\x02\x38\"3/loadtesting/agent/v1/agents/externalAgentsRegister:\x01*Bt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.agent.v1.agent_registration_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent'
  _globals['_EXTERNALAGENTREGISTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_EXTERNALAGENTREGISTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_EXTERNALAGENTREGISTERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_EXTERNALAGENTREGISTERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_AGENTREGISTRATIONSERVICE'].methods_by_name['Register']._loaded_options = None
  _globals['_AGENTREGISTRATIONSERVICE'].methods_by_name['Register']._serialized_options = b'\202\323\344\223\002*\"%/loadtesting/agent/v1/agents/register:\001*'
  _globals['_AGENTREGISTRATIONSERVICE'].methods_by_name['ExternalAgentRegister']._loaded_options = None
  _globals['_AGENTREGISTRATIONSERVICE'].methods_by_name['ExternalAgentRegister']._serialized_options = b'\262\322*.\n\035ExternalAgentRegisterMetadata\022\rAgentInstance\202\323\344\223\0028\"3/loadtesting/agent/v1/agents/externalAgentsRegister:\001*'
  _globals['_REGISTERREQUEST']._serialized_start=240
  _globals['_REGISTERREQUEST']._serialized_end=309
  _globals['_REGISTERRESPONSE']._serialized_start=311
  _globals['_REGISTERRESPONSE']._serialized_end=356
  _globals['_EXTERNALAGENTREGISTERREQUEST']._serialized_start=359
  _globals['_EXTERNALAGENTREGISTERREQUEST']._serialized_end=676
  _globals['_EXTERNALAGENTREGISTERREQUEST_LABELSENTRY']._serialized_start=631
  _globals['_EXTERNALAGENTREGISTERREQUEST_LABELSENTRY']._serialized_end=676
  _globals['_EXTERNALAGENTREGISTERMETADATA']._serialized_start=678
  _globals['_EXTERNALAGENTREGISTERMETADATA']._serialized_end=736
  _globals['_AGENTREGISTRATIONSERVICE']._serialized_start=739
  _globals['_AGENTREGISTRATIONSERVICE']._serialized_end=1173
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.compute.v1.instance_pb2
import yandex.cloud.compute.v1.instance_service_pb2
import yandex.cloud.compute.v1.reserved_instance_pool_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetReservedInstancePoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESERVED_INSTANCE_POOL_ID_FIELD_NUMBER: builtins.int
    reserved_instance_pool_id: builtins.str
    """ID of the reserved instance pool resource to return.
    To get the reserved instance pool ID, use a [ReservedInstancePoolService.List] request.
    """
    def __init__(
        self,
        *,
        reserved_instance_pool_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["reserved_instance_pool_id", b"reserved_instance_pool_id"]) -> None: ...

global___GetReservedInstancePoolRequest = GetReservedInstancePoolRequest

@typing.final
class ListReservedInstancePoolsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the Folder to list reserved instance pools in.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListReservedInstancePoolsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListReservedInstancePoolsResponse.next_page_token]
    returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression consists of one or more conditions united by `AND` operator: `<condition1> [AND <condition2> [<...> AND <conditionN>]]`.

    Each condition has the form `<field> <operator> <value>`, where:
    1. `<field>` is the field name. Currently you can use filtering only on the limited number of fields.
    2. `<operator>` is a logical operator, one of `=`, `!=`, `IN`, `NOT IN`.
    3. `<value>` represents a value.
    String values should be written in double (`"`) or single (`'`) quotes. C-style escape sequences are supported (`\\"` turns to `"`, `\\'` to `'`, `\\\\` to backslash).
    """
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "id asc" if omitted.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListReservedInstancePoolsRequest = ListReservedInstancePoolsRequest

@typing.final
class ListReservedInstancePoolsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESERVED_INSTANCE_POOLS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListReservedInstancePoolsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListReservedInstancePoolsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def reserved_instance_pools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.reserved_instance_pool_pb2.ReservedInstancePool]:
        """List of reserved instance pool resources."""

    def __init__(
        self,
        *,
        reserved_instance_pools: collections.abc.Iterable[yandex.cloud.compute.v1.reserved_instance_pool_pb2.ReservedInstancePool] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "reserved_instance_pools", b"reserved_instance_pools"]) -> None: ...

global___ListReservedInstancePoolsResponse = ListReservedInstancePoolsResponse

@typing.final
class CreateReservedInstancePoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    PLATFORM_ID_FIELD_NUMBER: builtins.int
    RESOURCES_SPEC_FIELD_NUMBER: builtins.int
    GPU_SETTINGS_FIELD_NUMBER: builtins.int
    BOOT_DISK_SPEC_FIELD_NUMBER: builtins.int
    NETWORK_SETTINGS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the reserved instance pool."""
    description: builtins.str
    """Description of the reserved instance pool."""
    zone_id: builtins.str
    """ID of the availability zone where the reserved instance pool resides.
    To get a list of available zones, use the [yandex.cloud.compute.v1.ZoneService.List] request
    """
    folder_id: builtins.str
    """ID of the folder to create the reserved instance pool in.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    platform_id: builtins.str
    """ID of the hardware platform configuration for the reserved instance pool.
    This field affects the available values in [resources_spec] field.

    For more information, see [Platforms](/docs/compute/concepts/vm-platforms).
    """
    size: builtins.int
    """Desired size of the pool (number of slots for instances in this pool)."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def resources_spec(self) -> yandex.cloud.compute.v1.instance_service_pb2.ResourcesSpec:
        """Computing resources of the reserved instance pool instances, such as the amount of memory and number of cores.
        To get a list of available values, see [Levels of core performance](/docs/compute/concepts/performance-levels).
        """

    @property
    def gpu_settings(self) -> yandex.cloud.compute.v1.instance_pb2.GpuSettings:
        """GPU settings."""

    @property
    def boot_disk_spec(self) -> yandex.cloud.compute.v1.reserved_instance_pool_pb2.BootDiskSpec:
        """Spec is used to determine which License IDs should be allowed for instances created in the pool."""

    @property
    def network_settings(self) -> yandex.cloud.compute.v1.instance_pb2.NetworkSettings:
        """Network settings."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zone_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        platform_id: builtins.str = ...,
        resources_spec: yandex.cloud.compute.v1.instance_service_pb2.ResourcesSpec | None = ...,
        gpu_settings: yandex.cloud.compute.v1.instance_pb2.GpuSettings | None = ...,
        boot_disk_spec: yandex.cloud.compute.v1.reserved_instance_pool_pb2.BootDiskSpec | None = ...,
        network_settings: yandex.cloud.compute.v1.instance_pb2.NetworkSettings | None = ...,
        size: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["boot_disk_spec", b"boot_disk_spec", "gpu_settings", b"gpu_settings", "network_settings", b"network_settings", "resources_spec", b"resources_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["boot_disk_spec", b"boot_disk_spec", "description", b"description", "folder_id", b"folder_id", "gpu_settings", b"gpu_settings", "labels", b"labels", "name", b"name", "network_settings", b"network_settings", "platform_id", b"platform_id", "resources_spec", b"resources_spec", "size", b"size", "zone_id", b"zone_id"]) -> None: ...

global___CreateReservedInstancePoolRequest = CreateReservedInstancePoolRequest

@typing.final
class CreateReservedInstancePoolMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESERVED_INSTANCE_POOL_ID_FIELD_NUMBER: builtins.int
    reserved_instance_pool_id: builtins.str
    """ID of the reserved instance pool that is being created."""
    def __init__(
        self,
        *,
        reserved_instance_pool_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["reserved_instance_pool_id", b"reserved_instance_pool_id"]) -> None: ...

global___CreateReservedInstancePoolMetadata = CreateReservedInstancePoolMetadata

@typing.final
class UpdateReservedInstancePoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESERVED_INSTANCE_POOL_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    reserved_instance_pool_id: builtins.str
    """ID of the reserved instance pool to update.
    To get the reserved instance pool ID, use a [ReservedInstancePoolService.List] request.
    """
    name: builtins.str
    """New name for the reserved instance pool."""
    description: builtins.str
    """Description of the reserved instance pool."""
    size: builtins.int
    """Desired size of the pool."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the reserved instance pool should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs.

        Existing set of `labels` is completely replaced by the provided set.
        """

    def __init__(
        self,
        *,
        reserved_instance_pool_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        size: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "name", b"name", "reserved_instance_pool_id", b"reserved_instance_pool_id", "size", b"size", "update_mask", b"update_mask"]) -> None: ...

global___UpdateReservedInstancePoolRequest = UpdateReservedInstancePoolRequest

@typing.final
class UpdateReservedInstancePoolMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESERVED_INSTANCE_POOL_ID_FIELD_NUMBER: builtins.int
    reserved_instance_pool_id: builtins.str
    """ID of the reserved instance pool that is being updated."""
    def __init__(
        self,
        *,
        reserved_instance_pool_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["reserved_instance_pool_id", b"reserved_instance_pool_id"]) -> None: ...

global___UpdateReservedInstancePoolMetadata = UpdateReservedInstancePoolMetadata

@typing.final
class DeleteReservedInstancePoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESERVED_INSTANCE_POOL_ID_FIELD_NUMBER: builtins.int
    reserved_instance_pool_id: builtins.str
    """ID of the reserved instance pool to delete.
    To get the reserved instance pool ID, use a [ReservedInstancePoolService.List] request.
    """
    def __init__(
        self,
        *,
        reserved_instance_pool_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["reserved_instance_pool_id", b"reserved_instance_pool_id"]) -> None: ...

global___DeleteReservedInstancePoolRequest = DeleteReservedInstancePoolRequest

@typing.final
class DeleteReservedInstancePoolMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESERVED_INSTANCE_POOL_ID_FIELD_NUMBER: builtins.int
    reserved_instance_pool_id: builtins.str
    """ID of the reserved instance pool that is being deleted."""
    def __init__(
        self,
        *,
        reserved_instance_pool_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["reserved_instance_pool_id", b"reserved_instance_pool_id"]) -> None: ...

global___DeleteReservedInstancePoolMetadata = DeleteReservedInstancePoolMetadata

@typing.final
class DeleteReservedInstancePoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteReservedInstancePoolResponse = DeleteReservedInstancePoolResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/spqr/v1/database_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/spqr/v1/database_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.spqr.v1 import database_pb2 as yandex_dot_cloud_dot_mdb_dot_spqr_dot_v1_dot_database__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/mdb/spqr/v1/database_service.proto\x12\x18yandex.cloud.mdb.spqr.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\'yandex/cloud/mdb/spqr/v1/database.proto\"m\n\x12GetDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rdatabase_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"v\n\x14ListDatabasesRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x9a\x01\n\x1eListDatabasesAtRevisionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x18\n\x08revision\x18\x04 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"g\n\x15ListDatabasesResponse\x12\x35\n\tdatabases\x18\x01 \x03(\x0b\x32\".yandex.cloud.mdb.spqr.v1.Database\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"~\n\x15\x43reateDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x43\n\rdatabase_spec\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.spqr.v1.DatabaseSpecB\x04\xe8\xc7\x31\x01\"C\n\x16\x43reateDatabaseMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"p\n\x15\x44\x65leteDatabaseRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\rdatabase_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\"C\n\x16\x44\x65leteDatabaseMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t2\xaf\x07\n\x0f\x44\x61tabaseService\x12\xa1\x01\n\x03Get\x12,.yandex.cloud.mdb.spqr.v1.GetDatabaseRequest\x1a\".yandex.cloud.mdb.spqr.v1.Database\"H\x82\xd3\xe4\x93\x02\x42\x12@/managed-spqr/v1/clusters/{cluster_id}/databases/{database_name}\x12\xa1\x01\n\x04List\x12..yandex.cloud.mdb.spqr.v1.ListDatabasesRequest\x1a/.yandex.cloud.mdb.spqr.v1.ListDatabasesResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/managed-spqr/v1/clusters/{cluster_id}/databases\x12\xb5\x01\n\x0eListAtRevision\x12\x38.yandex.cloud.mdb.spqr.v1.ListDatabasesAtRevisionRequest\x1a/.yandex.cloud.mdb.spqr.v1.ListDatabasesResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/managed-spqr/v1/clusters/{cluster_id}/databases\x12\xbf\x01\n\x06\x43reate\x12/.yandex.cloud.mdb.spqr.v1.CreateDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*\"\n\x16\x43reateDatabaseMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02\x35\"0/managed-spqr/v1/clusters/{cluster_id}/databases:\x01*\x12\xd9\x01\n\x06\x44\x65lete\x12/.yandex.cloud.mdb.spqr.v1.DeleteDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*/\n\x16\x44\x65leteDatabaseMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x42*@/managed-spqr/v1/clusters/{cluster_id}/databases/{database_name}Ba\n\x1cyandex.cloud.api.mdb.spqr.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/spqr/v1;spqrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.spqr.v1.database_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034yandex.cloud.api.mdb.spqr.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/spqr/v1;spqr'
  _globals['_GETDATABASEREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETDATABASEREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETDATABASEREQUEST'].fields_by_name['database_name']._loaded_options = None
  _globals['_GETDATABASEREQUEST'].fields_by_name['database_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_LISTDATABASESREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTDATABASESREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDATABASESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDATABASESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTDATABASESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDATABASESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTDATABASESATREVISIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTDATABASESATREVISIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDATABASESATREVISIONREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDATABASESATREVISIONREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTDATABASESATREVISIONREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDATABASESATREVISIONREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTDATABASESATREVISIONREQUEST'].fields_by_name['revision']._loaded_options = None
  _globals['_LISTDATABASESATREVISIONREQUEST'].fields_by_name['revision']._serialized_options = b'\372\3071\002>0'
  _globals['_CREATEDATABASEREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATEDATABASEREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEDATABASEREQUEST'].fields_by_name['database_spec']._loaded_options = None
  _globals['_CREATEDATABASEREQUEST'].fields_by_name['database_spec']._serialized_options = b'\350\3071\001'
  _globals['_DELETEDATABASEREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETEDATABASEREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEDATABASEREQUEST'].fields_by_name['database_name']._loaded_options = None
  _globals['_DELETEDATABASEREQUEST'].fields_by_name['database_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_DATABASESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_DATABASESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002B\022@/managed-spqr/v1/clusters/{cluster_id}/databases/{database_name}'
  _globals['_DATABASESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_DATABASESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\0022\0220/managed-spqr/v1/clusters/{cluster_id}/databases'
  _globals['_DATABASESERVICE'].methods_by_name['ListAtRevision']._loaded_options = None
  _globals['_DATABASESERVICE'].methods_by_name['ListAtRevision']._serialized_options = b'\202\323\344\223\0022\0220/managed-spqr/v1/clusters/{cluster_id}/databases'
  _globals['_DATABASESERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_DATABASESERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateDatabaseMetadata\022\010Database\202\323\344\223\0025\"0/managed-spqr/v1/clusters/{cluster_id}/databases:\001*'
  _globals['_DATABASESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_DATABASESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteDatabaseMetadata\022\025google.protobuf.Empty\202\323\344\223\002B*@/managed-spqr/v1/clusters/{cluster_id}/databases/{database_name}'
  _globals['_GETDATABASEREQUEST']._serialized_start=253
  _globals['_GETDATABASEREQUEST']._serialized_end=362
  _globals['_LISTDATABASESREQUEST']._serialized_start=364
  _globals['_LISTDATABASESREQUEST']._serialized_end=482
  _globals['_LISTDATABASESATREVISIONREQUEST']._serialized_start=485
  _globals['_LISTDATABASESATREVISIONREQUEST']._serialized_end=639
  _globals['_LISTDATABASESRESPONSE']._serialized_start=641
  _globals['_LISTDATABASESRESPONSE']._serialized_end=744
  _globals['_CREATEDATABASEREQUEST']._serialized_start=746
  _globals['_CREATEDATABASEREQUEST']._serialized_end=872
  _globals['_CREATEDATABASEMETADATA']._serialized_start=874
  _globals['_CREATEDATABASEMETADATA']._serialized_end=941
  _globals['_DELETEDATABASEREQUEST']._serialized_start=943
  _globals['_DELETEDATABASEREQUEST']._serialized_end=1055
  _globals['_DELETEDATABASEMETADATA']._serialized_start=1057
  _globals['_DELETEDATABASEMETADATA']._serialized_end=1124
  _globals['_DATABASESERVICE']._serialized_start=1127
  _globals['_DATABASESERVICE']._serialized_end=2070
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/spqr/v1/config.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/spqr/v1/config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%yandex/cloud/mdb/spqr/v1/config.proto\x12\x18yandex.cloud.mdb.spqr.v1\x1a\x1dyandex/cloud/validation.proto\x1a\x1egoogle/protobuf/wrappers.proto\")\n\rMDBPostgreSQL\x12\x18\n\ncluster_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xf7\x02\n\nSPQRConfig\x12\x36\n\x06router\x18\x01 \x01(\x0b\x32&.yandex.cloud.mdb.spqr.v1.RouterConfig\x12@\n\x0b\x63oordinator\x18\x02 \x01(\x0b\x32+.yandex.cloud.mdb.spqr.v1.CoordinatorConfig\x12>\n\npostgresql\x18\x03 \x01(\x0b\x32*.yandex.cloud.mdb.spqr.v1.PostgreSQLConfig\x12\x34\n\x05infra\x18\x05 \x01(\x0b\x32%.yandex.cloud.mdb.spqr.v1.InfraConfig\x12\x35\n\tlog_level\x18\x06 \x01(\x0e\x32\".yandex.cloud.mdb.spqr.v1.LogLevel\x12<\n\x08\x62\x61lancer\x18\x07 \x01(\x0b\x32*.yandex.cloud.mdb.spqr.v1.BalancerSettingsJ\x04\x08\x04\x10\x05\"\x80\x01\n\x0cRouterConfig\x12\x38\n\x06\x63onfig\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.spqr.v1.RouterSettings\x12\x36\n\tresources\x18\x02 \x01(\x0b\x32#.yandex.cloud.mdb.spqr.v1.Resources\"\x8a\x01\n\x11\x43oordinatorConfig\x12=\n\x06\x63onfig\x18\x01 \x01(\x0b\x32-.yandex.cloud.mdb.spqr.v1.CoordinatorSettings\x12\x36\n\tresources\x18\x02 \x01(\x0b\x32#.yandex.cloud.mdb.spqr.v1.Resources\"\x88\x01\n\x10PostgreSQLConfig\x12<\n\x06\x63onfig\x18\x01 \x01(\x0b\x32,.yandex.cloud.mdb.spqr.v1.PostgreSQLSettings\x12\x36\n\tresources\x18\x02 \x01(\x0b\x32#.yandex.cloud.mdb.spqr.v1.Resources\"\xc3\x01\n\x0bInfraConfig\x12\x36\n\tresources\x18\x02 \x01(\x0b\x32#.yandex.cloud.mdb.spqr.v1.Resources\x12\x38\n\x06router\x18\x03 \x01(\x0b\x32(.yandex.cloud.mdb.spqr.v1.RouterSettings\x12\x42\n\x0b\x63oordinator\x18\x04 \x01(\x0b\x32-.yandex.cloud.mdb.spqr.v1.CoordinatorSettings\"\xcd\x02\n\x10\x42\x61lancerSettings\x12\x33\n\rcpu_threshold\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x35\n\x0fspace_threshold\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x36\n\x11stat_interval_sec\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0emax_move_count\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\rkeys_per_move\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12,\n\x07timeout\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xe0\x02\n\x0eRouterSettings\x12\x38\n\x14show_notice_messages\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x16\n\x0etime_quantiles\x18\x02 \x03(\x01\x12]\n\x16\x64\x65\x66\x61ult_route_behavior\x18\x04 \x01(\x0e\x32=.yandex.cloud.mdb.spqr.v1.RouterSettings.DefaultRouteBehavior\x12\x41\n\x1dprefer_same_availability_zone\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"T\n\x14\x44\x65\x66\x61ultRouteBehavior\x12&\n\"DEFAULT_ROUTE_BEHAVIOR_UNSPECIFIED\x10\x00\x12\t\n\x05\x42LOCK\x10\x01\x12\t\n\x05\x41LLOW\x10\x02J\x04\x08\x03\x10\x04\"\x15\n\x13\x43oordinatorSettings\"\x14\n\x12PostgreSQLSettings\"P\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x11\n\tdisk_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x64isk_type_id\x18\x03 \x01(\t*h\n\x08LogLevel\x12\x19\n\x15LOG_LEVEL_UNSPECIFIED\x10\x00\x12\t\n\x05\x44\x45\x42UG\x10\x01\x12\x08\n\x04INFO\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\t\n\x05\x46\x41TAL\x10\x05\x12\t\n\x05PANIC\x10\x06\x42\x61\n\x1cyandex.cloud.api.mdb.spqr.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/spqr/v1;spqrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.spqr.v1.config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034yandex.cloud.api.mdb.spqr.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/spqr/v1;spqr'
  _globals['_MDBPOSTGRESQL'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_MDBPOSTGRESQL'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001'
  _globals['_LOGLEVEL']._serialized_start=1978
  _globals['_LOGLEVEL']._serialized_end=2082
  _globals['_MDBPOSTGRESQL']._serialized_start=130
  _globals['_MDBPOSTGRESQL']._serialized_end=171
  _globals['_SPQRCONFIG']._serialized_start=174
  _globals['_SPQRCONFIG']._serialized_end=549
  _globals['_ROUTERCONFIG']._serialized_start=552
  _globals['_ROUTERCONFIG']._serialized_end=680
  _globals['_COORDINATORCONFIG']._serialized_start=683
  _globals['_COORDINATORCONFIG']._serialized_end=821
  _globals['_POSTGRESQLCONFIG']._serialized_start=824
  _globals['_POSTGRESQLCONFIG']._serialized_end=960
  _globals['_INFRACONFIG']._serialized_start=963
  _globals['_INFRACONFIG']._serialized_end=1158
  _globals['_BALANCERSETTINGS']._serialized_start=1161
  _globals['_BALANCERSETTINGS']._serialized_end=1494
  _globals['_ROUTERSETTINGS']._serialized_start=1497
  _globals['_ROUTERSETTINGS']._serialized_end=1849
  _globals['_ROUTERSETTINGS_DEFAULTROUTEBEHAVIOR']._serialized_start=1759
  _globals['_ROUTERSETTINGS_DEFAULTROUTEBEHAVIOR']._serialized_end=1843
  _globals['_COORDINATORSETTINGS']._serialized_start=1851
  _globals['_COORDINATORSETTINGS']._serialized_end=1872
  _globals['_POSTGRESQLSETTINGS']._serialized_start=1874
  _globals['_POSTGRESQLSETTINGS']._serialized_end=1894
  _globals['_RESOURCES']._serialized_start=1896
  _globals['_RESOURCES']._serialized_end=1976
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.greenplum.v1.resource_groups_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateResourceGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    resource_group_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        resource_group_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "resource_group_name", b"resource_group_name"]) -> None: ...

global___CreateResourceGroupMetadata = CreateResourceGroupMetadata

@typing.final
class UpdateResourceGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    resource_group_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        resource_group_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "resource_group_name", b"resource_group_name"]) -> None: ...

global___UpdateResourceGroupMetadata = UpdateResourceGroupMetadata

@typing.final
class DeleteResourceGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    resource_group_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        resource_group_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "resource_group_name", b"resource_group_name"]) -> None: ...

global___DeleteResourceGroupMetadata = DeleteResourceGroupMetadata

@typing.final
class ListResourceGroupsRequest(google.protobuf.message.Message):
    """ResourceGroups API"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___ListResourceGroupsRequest = ListResourceGroupsRequest

@typing.final
class ListResourceGroupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_GROUPS_FIELD_NUMBER: builtins.int
    @property
    def resource_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.greenplum.v1.resource_groups_pb2.ResourceGroup]: ...
    def __init__(
        self,
        *,
        resource_groups: collections.abc.Iterable[yandex.cloud.mdb.greenplum.v1.resource_groups_pb2.ResourceGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resource_groups", b"resource_groups"]) -> None: ...

global___ListResourceGroupsResponse = ListResourceGroupsResponse

@typing.final
class GetResourceGroupAtRevisionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Greenplum cluster."""
    revision: builtins.int
    """Cluster revision"""
    resource_group_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        revision: builtins.int = ...,
        resource_group_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "resource_group_name", b"resource_group_name", "revision", b"revision"]) -> None: ...

global___GetResourceGroupAtRevisionRequest = GetResourceGroupAtRevisionRequest

@typing.final
class CreateResourceGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    @property
    def resource_group(self) -> yandex.cloud.mdb.greenplum.v1.resource_groups_pb2.ResourceGroup: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        resource_group: yandex.cloud.mdb.greenplum.v1.resource_groups_pb2.ResourceGroup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource_group", b"resource_group"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "resource_group", b"resource_group"]) -> None: ...

global___CreateResourceGroupRequest = CreateResourceGroupRequest

@typing.final
class UpdateResourceGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def resource_group(self) -> yandex.cloud.mdb.greenplum.v1.resource_groups_pb2.ResourceGroup: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        resource_group: yandex.cloud.mdb.greenplum.v1.resource_groups_pb2.ResourceGroup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource_group", b"resource_group", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "resource_group", b"resource_group", "update_mask", b"update_mask"]) -> None: ...

global___UpdateResourceGroupRequest = UpdateResourceGroupRequest

@typing.final
class DeleteResourceGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    resource_group_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        resource_group_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "resource_group_name", b"resource_group_name"]) -> None: ...

global___DeleteResourceGroupRequest = DeleteResourceGroupRequest



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/k8s/v1/version.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/k8s/v1/version.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!yandex/cloud/k8s/v1/version.proto\x12\x13yandex.cloud.k8s.v1\x1a\x1dyandex/cloud/validation.proto\"\x80\x01\n\x0bVersionInfo\x12\x17\n\x0f\x63urrent_version\x18\x01 \x01(\t\x12\x1e\n\x16new_revision_available\x18\x02 \x01(\x08\x12\x1c\n\x14new_revision_summary\x18\x03 \x01(\t\x12\x1a\n\x12version_deprecated\x18\x04 \x01(\x08\"T\n\x11UpdateVersionSpec\x12\x11\n\x07version\x18\x01 \x01(\tH\x00\x12\x19\n\x0flatest_revision\x18\x02 \x01(\x08H\x00\x42\x11\n\tspecifier\x12\x04\xc0\xc1\x31\x01\x42V\n\x17yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8sb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.k8s.v1.version_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8s'
  _globals['_UPDATEVERSIONSPEC'].oneofs_by_name['specifier']._loaded_options = None
  _globals['_UPDATEVERSIONSPEC'].oneofs_by_name['specifier']._serialized_options = b'\300\3011\001'
  _globals['_VERSIONINFO']._serialized_start=90
  _globals['_VERSIONINFO']._serialized_end=218
  _globals['_UPDATEVERSIONSPEC']._serialized_start=220
  _globals['_UPDATEVERSIONSPEC']._serialized_end=304
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/sqlserver/v1/user_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/sqlserver/v1/user_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.sqlserver.v1 import user_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/mdb/sqlserver/v1/user_service.proto\x12\x1dyandex.cloud.mdb.sqlserver.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a(yandex/cloud/mdb/sqlserver/v1/user.proto\"d\n\x0eGetUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\"r\n\x10ListUsersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"`\n\x11ListUsersResponse\x12\x32\n\x05users\x18\x01 \x03(\x0b\x32#.yandex.cloud.mdb.sqlserver.v1.User\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"w\n\x11\x43reateUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12@\n\tuser_spec\x18\x02 \x01(\x0b\x32\'.yandex.cloud.mdb.sqlserver.v1.UserSpecB\x04\xe8\xc7\x31\x01\";\n\x12\x43reateUserMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\"\xb6\x02\n\x11UpdateUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1b\n\x08password\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05\x38-128\x12>\n\x0bpermissions\x18\x05 \x03(\x0b\x32).yandex.cloud.mdb.sqlserver.v1.Permission\x12?\n\x0cserver_roles\x18\x06 \x03(\x0e\x32).yandex.cloud.mdb.sqlserver.v1.ServerRole\";\n\x12UpdateUserMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\"g\n\x11\x44\x65leteUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\";\n\x12\x44\x65leteUserMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\"\xb5\x01\n\x1aGrantUserPermissionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\x12\x43\n\npermission\x18\x03 \x01(\x0b\x32).yandex.cloud.mdb.sqlserver.v1.PermissionB\x04\xe8\xc7\x31\x01\"D\n\x1bGrantUserPermissionMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\"\xb6\x01\n\x1bRevokeUserPermissionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\x12\x43\n\npermission\x18\x03 \x01(\x0b\x32).yandex.cloud.mdb.sqlserver.v1.PermissionB\x04\xe8\xc7\x31\x01\"E\n\x1cRevokeUserPermissionMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t2\xff\n\n\x0bUserService\x12\x9c\x01\n\x03Get\x12-.yandex.cloud.mdb.sqlserver.v1.GetUserRequest\x1a#.yandex.cloud.mdb.sqlserver.v1.User\"A\x82\xd3\xe4\x93\x02;\x12\x39/mdb/sqlserver/v1/clusters/{cluster_id}/users/{user_name}\x12\xa0\x01\n\x04List\x12/.yandex.cloud.mdb.sqlserver.v1.ListUsersRequest\x1a\x30.yandex.cloud.mdb.sqlserver.v1.ListUsersResponse\"5\x82\xd3\xe4\x93\x02/\x12-/mdb/sqlserver/v1/clusters/{cluster_id}/users\x12\xb5\x01\n\x06\x43reate\x12\x30.yandex.cloud.mdb.sqlserver.v1.CreateUserRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*\x1a\n\x12\x43reateUserMetadata\x12\x04User\x82\xd3\xe4\x93\x02\x32\"-/mdb/sqlserver/v1/clusters/{cluster_id}/users:\x01*\x12\xc1\x01\n\x06Update\x12\x30.yandex.cloud.mdb.sqlserver.v1.UpdateUserRequest\x1a!.yandex.cloud.operation.Operation\"b\xb2\xd2*\x1a\n\x12UpdateUserMetadata\x12\x04User\x82\xd3\xe4\x93\x02>29/mdb/sqlserver/v1/clusters/{cluster_id}/users/{user_name}:\x01*\x12\xcf\x01\n\x06\x44\x65lete\x12\x30.yandex.cloud.mdb.sqlserver.v1.DeleteUserRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*+\n\x12\x44\x65leteUserMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02;*9/mdb/sqlserver/v1/clusters/{cluster_id}/users/{user_name}\x12\xec\x01\n\x0fGrantPermission\x12\x39.yandex.cloud.mdb.sqlserver.v1.GrantUserPermissionRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*#\n\x1bGrantUserPermissionMetadata\x12\x04User\x82\xd3\xe4\x93\x02N\"I/mdb/sqlserver/v1/clusters/{cluster_id}/users/{user_name}:grantPermission:\x01*\x12\xf0\x01\n\x10RevokePermission\x12:.yandex.cloud.mdb.sqlserver.v1.RevokeUserPermissionRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*$\n\x1cRevokeUserPermissionMetadata\x12\x04User\x82\xd3\xe4\x93\x02O\"J/mdb/sqlserver/v1/clusters/{cluster_id}/users/{user_name}:revokePermission:\x01*Bv\n!yandex.cloud.api.mdb.sqlserver.v1B\x04PSUSZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserverb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.sqlserver.v1.user_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.sqlserver.v1B\004PSUSZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserver'
  _globals['_GETUSERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETUSERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETUSERREQUEST'].fields_by_name['user_name']._loaded_options = None
  _globals['_GETUSERREQUEST'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _globals['_LISTUSERSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATEUSERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEUSERREQUEST'].fields_by_name['user_spec']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['user_spec']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user_name']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['password']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['password']._serialized_options = b'\212\3101\0058-128'
  _globals['_DELETEUSERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETEUSERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEUSERREQUEST'].fields_by_name['user_name']._loaded_options = None
  _globals['_DELETEUSERREQUEST'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _globals['_GRANTUSERPERMISSIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GRANTUSERPERMISSIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GRANTUSERPERMISSIONREQUEST'].fields_by_name['user_name']._loaded_options = None
  _globals['_GRANTUSERPERMISSIONREQUEST'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _globals['_GRANTUSERPERMISSIONREQUEST'].fields_by_name['permission']._loaded_options = None
  _globals['_GRANTUSERPERMISSIONREQUEST'].fields_by_name['permission']._serialized_options = b'\350\3071\001'
  _globals['_REVOKEUSERPERMISSIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_REVOKEUSERPERMISSIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_REVOKEUSERPERMISSIONREQUEST'].fields_by_name['user_name']._loaded_options = None
  _globals['_REVOKEUSERPERMISSIONREQUEST'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _globals['_REVOKEUSERPERMISSIONREQUEST'].fields_by_name['permission']._loaded_options = None
  _globals['_REVOKEUSERPERMISSIONREQUEST'].fields_by_name['permission']._serialized_options = b'\350\3071\001'
  _globals['_USERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002;\0229/mdb/sqlserver/v1/clusters/{cluster_id}/users/{user_name}'
  _globals['_USERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002/\022-/mdb/sqlserver/v1/clusters/{cluster_id}/users'
  _globals['_USERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\032\n\022CreateUserMetadata\022\004User\202\323\344\223\0022\"-/mdb/sqlserver/v1/clusters/{cluster_id}/users:\001*'
  _globals['_USERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\032\n\022UpdateUserMetadata\022\004User\202\323\344\223\002>29/mdb/sqlserver/v1/clusters/{cluster_id}/users/{user_name}:\001*'
  _globals['_USERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*+\n\022DeleteUserMetadata\022\025google.protobuf.Empty\202\323\344\223\002;*9/mdb/sqlserver/v1/clusters/{cluster_id}/users/{user_name}'
  _globals['_USERSERVICE'].methods_by_name['GrantPermission']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['GrantPermission']._serialized_options = b'\262\322*#\n\033GrantUserPermissionMetadata\022\004User\202\323\344\223\002N\"I/mdb/sqlserver/v1/clusters/{cluster_id}/users/{user_name}:grantPermission:\001*'
  _globals['_USERSERVICE'].methods_by_name['RevokePermission']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['RevokePermission']._serialized_options = b'\262\322*$\n\034RevokeUserPermissionMetadata\022\004User\202\323\344\223\002O\"J/mdb/sqlserver/v1/clusters/{cluster_id}/users/{user_name}:revokePermission:\001*'
  _globals['_GETUSERREQUEST']._serialized_start=294
  _globals['_GETUSERREQUEST']._serialized_end=394
  _globals['_LISTUSERSREQUEST']._serialized_start=396
  _globals['_LISTUSERSREQUEST']._serialized_end=510
  _globals['_LISTUSERSRESPONSE']._serialized_start=512
  _globals['_LISTUSERSRESPONSE']._serialized_end=608
  _globals['_CREATEUSERREQUEST']._serialized_start=610
  _globals['_CREATEUSERREQUEST']._serialized_end=729
  _globals['_CREATEUSERMETADATA']._serialized_start=731
  _globals['_CREATEUSERMETADATA']._serialized_end=790
  _globals['_UPDATEUSERREQUEST']._serialized_start=793
  _globals['_UPDATEUSERREQUEST']._serialized_end=1103
  _globals['_UPDATEUSERMETADATA']._serialized_start=1105
  _globals['_UPDATEUSERMETADATA']._serialized_end=1164
  _globals['_DELETEUSERREQUEST']._serialized_start=1166
  _globals['_DELETEUSERREQUEST']._serialized_end=1269
  _globals['_DELETEUSERMETADATA']._serialized_start=1271
  _globals['_DELETEUSERMETADATA']._serialized_end=1330
  _globals['_GRANTUSERPERMISSIONREQUEST']._serialized_start=1333
  _globals['_GRANTUSERPERMISSIONREQUEST']._serialized_end=1514
  _globals['_GRANTUSERPERMISSIONMETADATA']._serialized_start=1516
  _globals['_GRANTUSERPERMISSIONMETADATA']._serialized_end=1584
  _globals['_REVOKEUSERPERMISSIONREQUEST']._serialized_start=1587
  _globals['_REVOKEUSERPERMISSIONREQUEST']._serialized_end=1769
  _globals['_REVOKEUSERPERMISSIONMETADATA']._serialized_start=1771
  _globals['_REVOKEUSERPERMISSIONMETADATA']._serialized_end=1840
  _globals['_USERSERVICE']._serialized_start=1843
  _globals['_USERSERVICE']._serialized_end=3250
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Group(google.protobuf.message.Message):
    """A Group resource.
    For more information, see [Groups](/docs/organization/operations/manage-groups).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the group."""
    organization_id: builtins.str
    """ID of the organization that the group belongs to."""
    name: builtins.str
    """Name of the group."""
    description: builtins.str
    """Description of the group."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        organization_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "id", b"id", "name", b"name", "organization_id", b"organization_id"]) -> None: ...

global___Group = Group



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.datatransfer.v1.endpoint.common_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _MetrikaStreamType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MetrikaStreamTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MetrikaStreamType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    METRIKA_STREAM_TYPE_UNSPECIFIED: _MetrikaStreamType.ValueType  # 0
    METRIKA_STREAM_TYPE_HITS: _MetrikaStreamType.ValueType  # 1
    METRIKA_STREAM_TYPE_VISITS: _MetrikaStreamType.ValueType  # 2
    METRIKA_STREAM_TYPE_HITS_V2: _MetrikaStreamType.ValueType  # 3

class MetrikaStreamType(_MetrikaStreamType, metaclass=_MetrikaStreamTypeEnumTypeWrapper): ...

METRIKA_STREAM_TYPE_UNSPECIFIED: MetrikaStreamType.ValueType  # 0
METRIKA_STREAM_TYPE_HITS: MetrikaStreamType.ValueType  # 1
METRIKA_STREAM_TYPE_VISITS: MetrikaStreamType.ValueType  # 2
METRIKA_STREAM_TYPE_HITS_V2: MetrikaStreamType.ValueType  # 3
global___MetrikaStreamType = MetrikaStreamType

@typing.final
class MetrikaStream(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    type: global___MetrikaStreamType.ValueType
    @property
    def columns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        type: global___MetrikaStreamType.ValueType = ...,
        columns: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["columns", b"columns", "type", b"type"]) -> None: ...

global___MetrikaStream = MetrikaStream

@typing.final
class MetrikaSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNTER_IDS_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    STREAMS_FIELD_NUMBER: builtins.int
    @property
    def counter_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def token(self) -> yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret: ...
    @property
    def streams(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MetrikaStream]: ...
    def __init__(
        self,
        *,
        counter_ids: collections.abc.Iterable[builtins.int] | None = ...,
        token: yandex.cloud.datatransfer.v1.endpoint.common_pb2.Secret | None = ...,
        streams: collections.abc.Iterable[global___MetrikaStream] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["token", b"token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["counter_ids", b"counter_ids", "streams", b"streams", "token", b"token"]) -> None: ...

global___MetrikaSource = MetrikaSource



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/datatransfer/v1/endpoint/ydb.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/datatransfer/v1/endpoint/ydb.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/datatransfer/v1/endpoint/ydb.proto\x12%yandex.cloud.datatransfer.v1.endpoint\"\xf9\x01\n\tYdbSource\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\r\n\x05paths\x18\x05 \x03(\t\x12\x1a\n\x12service_account_id\x18\x06 \x01(\t\x12\x11\n\tsubnet_id\x18\x1e \x01(\t\x12\x16\n\x0esa_key_content\x18! \x01(\t\x12\x17\n\x0fsecurity_groups\x18\" \x03(\t\x12\x1e\n\x16\x63hangefeed_custom_name\x18# \x01(\t\x12\'\n\x1f\x63hangefeed_custom_consumer_name\x18$ \x01(\tJ\x04\x08\x03\x10\x05J\x04\x08\x07\x10\x1eJ\x04\x08\x1f\x10!\"\x83\x03\n\tYdbTarget\x12\x10\n\x08\x64\x61tabase\x18\x01 \x01(\t\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\n \x01(\t\x12\x1a\n\x12service_account_id\x18\x0b \x01(\t\x12O\n\x0e\x63leanup_policy\x18\x15 \x01(\x0e\x32\x37.yandex.cloud.datatransfer.v1.endpoint.YdbCleanupPolicy\x12\x11\n\tsubnet_id\x18\x1e \x01(\t\x12\x16\n\x0esa_key_content\x18  \x01(\t\x12\x17\n\x0fsecurity_groups\x18! \x03(\t\x12 \n\x18is_table_column_oriented\x18\" \x01(\x08\x12Y\n\x13\x64\x65\x66\x61ult_compression\x18# \x01(\x0e\x32<.yandex.cloud.datatransfer.v1.endpoint.YdbDefaultCompressionJ\x04\x08\x03\x10\nJ\x04\x08\x0c\x10\x15J\x04\x08\x16\x10\x1eJ\x04\x08\x1f\x10 *t\n\x10YdbCleanupPolicy\x12\"\n\x1eYDB_CLEANUP_POLICY_UNSPECIFIED\x10\x00\x12\x1f\n\x1bYDB_CLEANUP_POLICY_DISABLED\x10\x01\x12\x1b\n\x17YDB_CLEANUP_POLICY_DROP\x10\x02*\x87\x01\n\x15YdbDefaultCompression\x12\'\n#YDB_DEFAULT_COMPRESSION_UNSPECIFIED\x10\x00\x12$\n YDB_DEFAULT_COMPRESSION_DISABLED\x10\x01\x12\x1f\n\x1bYDB_DEFAULT_COMPRESSION_LZ4\x10\x02\x42\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datatransfer.v1.endpoint.ydb_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint'
  _globals['_YDBCLEANUPPOLICY']._serialized_start=732
  _globals['_YDBCLEANUPPOLICY']._serialized_end=848
  _globals['_YDBDEFAULTCOMPRESSION']._serialized_start=851
  _globals['_YDBDEFAULTCOMPRESSION']._serialized_end=986
  _globals['_YDBSOURCE']._serialized_start=91
  _globals['_YDBSOURCE']._serialized_end=340
  _globals['_YDBTARGET']._serialized_start=343
  _globals['_YDBTARGET']._serialized_end=730
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _RawLogsStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RawLogsStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RawLogsStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RAW_LOGS_STATUS_UNSPECIFIED: _RawLogsStatus.ValueType  # 0
    RAW_LOGS_STATUS_NOT_ACTIVATED: _RawLogsStatus.ValueType  # 1
    """Raw logs wasn't activated."""
    RAW_LOGS_STATUS_OK: _RawLogsStatus.ValueType  # 2
    """Raw logs was activated, and logs storing process works as expected."""
    RAW_LOGS_STATUS_FAILED: _RawLogsStatus.ValueType  # 3
    """Raw logs was activated, but CDN provider has been failed to store logs."""
    RAW_LOGS_STATUS_PENDING: _RawLogsStatus.ValueType  # 4
    """Raw logs was activated, but logs storing process is expected."""

class RawLogsStatus(_RawLogsStatus, metaclass=_RawLogsStatusEnumTypeWrapper):
    """Provider side statuses of Raw logs processing."""

RAW_LOGS_STATUS_UNSPECIFIED: RawLogsStatus.ValueType  # 0
RAW_LOGS_STATUS_NOT_ACTIVATED: RawLogsStatus.ValueType  # 1
"""Raw logs wasn't activated."""
RAW_LOGS_STATUS_OK: RawLogsStatus.ValueType  # 2
"""Raw logs was activated, and logs storing process works as expected."""
RAW_LOGS_STATUS_FAILED: RawLogsStatus.ValueType  # 3
"""Raw logs was activated, but CDN provider has been failed to store logs."""
RAW_LOGS_STATUS_PENDING: RawLogsStatus.ValueType  # 4
"""Raw logs was activated, but logs storing process is expected."""
global___RawLogsStatus = RawLogsStatus

@typing.final
class RawLogsSettings(google.protobuf.message.Message):
    """User settings for Raw logs."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_NAME_FIELD_NUMBER: builtins.int
    BUCKET_REGION_FIELD_NUMBER: builtins.int
    FILE_PREFIX_FIELD_NUMBER: builtins.int
    bucket_name: builtins.str
    """Destination S3 bucket name, note that the suer should be owner of the bucket."""
    bucket_region: builtins.str
    """Bucket region, unused for now, could be blank."""
    file_prefix: builtins.str
    """file_prefix: prefix each log object name with specified prefix.

    The prefix makes it simpler for you to locate the log objects.
    For example, if you specify the prefix value logs/, each log object that
    S3 creates begins with the logs/ prefix in its key, so pseudo S3 folders
    could be setup.
    """
    def __init__(
        self,
        *,
        bucket_name: builtins.str = ...,
        bucket_region: builtins.str = ...,
        file_prefix: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bucket_name", b"bucket_name", "bucket_region", b"bucket_region", "file_prefix", b"file_prefix"]) -> None: ...

global___RawLogsSettings = RawLogsSettings



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.speechsense.v1.audio_pb2
import yandex.cloud.speechsense.v1.search_pb2
import yandex.cloud.speechsense.v1.talk_pb2
import yandex.cloud.speechsense.v1.text_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _UserRole:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _UserRoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UserRole.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    USER_ROLE_UNSPECIFIED: _UserRole.ValueType  # 0
    USER_ROLE_OPERATOR: _UserRole.ValueType  # 1
    USER_ROLE_CLIENT: _UserRole.ValueType  # 2
    USER_ROLE_BOT: _UserRole.ValueType  # 3

class UserRole(_UserRole, metaclass=_UserRoleEnumTypeWrapper): ...

USER_ROLE_UNSPECIFIED: UserRole.ValueType  # 0
USER_ROLE_OPERATOR: UserRole.ValueType  # 1
USER_ROLE_CLIENT: UserRole.ValueType  # 2
USER_ROLE_BOT: UserRole.ValueType  # 3
global___UserRole = UserRole

@typing.final
class StreamTalkRequest(google.protobuf.message.Message):
    """streaming request to create audio dialog"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> global___TalkMetadata:
        """talk document metadata containing channel id and channel field values"""

    @property
    def audio(self) -> yandex.cloud.speechsense.v1.audio_pb2.AudioStreamingRequest:
        """audio metadata or chunk"""

    def __init__(
        self,
        *,
        metadata: global___TalkMetadata | None = ...,
        audio: yandex.cloud.speechsense.v1.audio_pb2.AudioStreamingRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["Event", b"Event", "audio", b"audio", "metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Event", b"Event", "audio", b"audio", "metadata", b"metadata"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["Event", b"Event"]) -> typing.Literal["metadata", "audio"] | None: ...

global___StreamTalkRequest = StreamTalkRequest

@typing.final
class UploadTalkRequest(google.protobuf.message.Message):
    """request to create audio dialog"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALK_ID_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    talk_id: builtins.str
    """talk_id, blank if initial upload request and present on metadata update"""
    @property
    def metadata(self) -> global___TalkMetadata: ...
    @property
    def audio(self) -> yandex.cloud.speechsense.v1.audio_pb2.AudioRequest:
        """audio payload"""

    def __init__(
        self,
        *,
        talk_id: builtins.str = ...,
        metadata: global___TalkMetadata | None = ...,
        audio: yandex.cloud.speechsense.v1.audio_pb2.AudioRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio", "metadata", b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio", "metadata", b"metadata", "talk_id", b"talk_id"]) -> None: ...

global___UploadTalkRequest = UploadTalkRequest

@typing.final
class UploadTalkResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALK_ID_FIELD_NUMBER: builtins.int
    talk_id: builtins.str
    """id of created talk document"""
    def __init__(
        self,
        *,
        talk_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["talk_id", b"talk_id"]) -> None: ...

global___UploadTalkResponse = UploadTalkResponse

@typing.final
class UploadTextRequest(google.protobuf.message.Message):
    """request to create text based dialog"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALK_ID_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TEXT_CONTENT_FIELD_NUMBER: builtins.int
    talk_id: builtins.str
    """talk_id, blank if initial upload request and present on metadata update"""
    @property
    def metadata(self) -> global___TalkMetadata: ...
    @property
    def text_content(self) -> yandex.cloud.speechsense.v1.text_pb2.TextContent: ...
    def __init__(
        self,
        *,
        talk_id: builtins.str = ...,
        metadata: global___TalkMetadata | None = ...,
        text_content: yandex.cloud.speechsense.v1.text_pb2.TextContent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["metadata", b"metadata", "text_content", b"text_content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["metadata", b"metadata", "talk_id", b"talk_id", "text_content", b"text_content"]) -> None: ...

global___UploadTextRequest = UploadTextRequest

@typing.final
class UploadTextResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALK_ID_FIELD_NUMBER: builtins.int
    talk_id: builtins.str
    """id of created talk document"""
    def __init__(
        self,
        *,
        talk_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["talk_id", b"talk_id"]) -> None: ...

global___UploadTextResponse = UploadTextResponse

@typing.final
class TalkMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class FieldsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONNECTION_ID_FIELD_NUMBER: builtins.int
    FIELDS_FIELD_NUMBER: builtins.int
    USERS_FIELD_NUMBER: builtins.int
    connection_id: builtins.str
    """id of connection this talk belongs too"""
    @property
    def fields(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """channel defined fields"""

    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UserMetadata]:
        """per user specific metadata"""

    def __init__(
        self,
        *,
        connection_id: builtins.str = ...,
        fields: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        users: collections.abc.Iterable[global___UserMetadata] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id", "fields", b"fields", "users", b"users"]) -> None: ...

global___TalkMetadata = TalkMetadata

@typing.final
class UserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class FieldsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    FIELDS_FIELD_NUMBER: builtins.int
    id: builtins.str
    role: global___UserRole.ValueType
    @property
    def fields(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        role: global___UserRole.ValueType = ...,
        fields: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["fields", b"fields", "id", b"id", "role", b"role"]) -> None: ...

global___UserMetadata = UserMetadata

@typing.final
class SearchTalkRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    SPACE_ID_FIELD_NUMBER: builtins.int
    CONNECTION_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    FILTERS_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    SORT_DATA_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """id of organization"""
    space_id: builtins.str
    """id of space"""
    connection_id: builtins.str
    """id of connection"""
    project_id: builtins.str
    """id of project"""
    page_size: builtins.int
    """page size, from 1 to 1000, default 100"""
    page_token: builtins.str
    """next page token, if page is not first"""
    @property
    def filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.speechsense.v1.search_pb2.Filter]:
        """metadata keys filters (user and system)"""

    @property
    def query(self) -> yandex.cloud.speechsense.v1.search_pb2.Query:
        """Full-text search query"""

    @property
    def sort_data(self) -> yandex.cloud.speechsense.v1.search_pb2.SortData:
        """talks sorting options"""

    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        space_id: builtins.str = ...,
        connection_id: builtins.str = ...,
        project_id: builtins.str = ...,
        filters: collections.abc.Iterable[yandex.cloud.speechsense.v1.search_pb2.Filter] | None = ...,
        query: yandex.cloud.speechsense.v1.search_pb2.Query | None = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        sort_data: yandex.cloud.speechsense.v1.search_pb2.SortData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["query", b"query", "sort_data", b"sort_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id", "filters", b"filters", "organization_id", b"organization_id", "page_size", b"page_size", "page_token", b"page_token", "project_id", b"project_id", "query", b"query", "sort_data", b"sort_data", "space_id", b"space_id"]) -> None: ...

global___SearchTalkRequest = SearchTalkRequest

@typing.final
class SearchTalkResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALK_IDS_FIELD_NUMBER: builtins.int
    TALKS_COUNT_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    talks_count: builtins.int
    """total documents matched"""
    next_page_token: builtins.str
    """page token for next request"""
    @property
    def talk_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """page results entries"""

    def __init__(
        self,
        *,
        talk_ids: collections.abc.Iterable[builtins.str] | None = ...,
        talks_count: builtins.int = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "talk_ids", b"talk_ids", "talks_count", b"talks_count"]) -> None: ...

global___SearchTalkResponse = SearchTalkResponse

@typing.final
class GetTalkRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    SPACE_ID_FIELD_NUMBER: builtins.int
    CONNECTION_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    TALK_IDS_FIELD_NUMBER: builtins.int
    RESULTS_MASK_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """id of organization"""
    space_id: builtins.str
    """id of space"""
    connection_id: builtins.str
    """id of connection to search data"""
    project_id: builtins.str
    """id of project to search data"""
    @property
    def talk_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """ids of talks to return. Requesting too many talks may result in "message exceeds maximum size" error.
        Up to 100 of talks per request is recommended.
        """

    @property
    def results_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """All types of analysis will be returned if not set."""

    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        space_id: builtins.str = ...,
        connection_id: builtins.str = ...,
        project_id: builtins.str = ...,
        talk_ids: collections.abc.Iterable[builtins.str] | None = ...,
        results_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["results_mask", b"results_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id", "organization_id", b"organization_id", "project_id", b"project_id", "results_mask", b"results_mask", "space_id", b"space_id", "talk_ids", b"talk_ids"]) -> None: ...

global___GetTalkRequest = GetTalkRequest

@typing.final
class GetTalkResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TALK_FIELD_NUMBER: builtins.int
    @property
    def talk(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.speechsense.v1.talk_pb2.Talk]: ...
    def __init__(
        self,
        *,
        talk: collections.abc.Iterable[yandex.cloud.speechsense.v1.talk_pb2.Talk] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["talk", b"talk"]) -> None: ...

global___GetTalkResponse = GetTalkResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.cdn.v1.rule_pb2
import yandex.cloud.cdn.v1.rule_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ResourceRulesServiceStub:
    """
    Rules management service.

    Used for Resources Rules management.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.rule_service_pb2.ListResourceRulesRequest,
        yandex.cloud.cdn.v1.rule_service_pb2.ListResourceRulesResponse,
    ]
    """List all rules for specified resource."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.rule_service_pb2.CreateResourceRuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create new resource rule with specified unique name and rule patter."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.rule_service_pb2.GetResourceRuleRequest,
        yandex.cloud.cdn.v1.rule_pb2.Rule,
    ]
    """Get specified by id resource rule."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.rule_service_pb2.UpdateResourceRuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update specified by id resource rule."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.rule_service_pb2.DeleteResourceRuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete specified by id resource rule."""

class ResourceRulesServiceAsyncStub:
    """
    Rules management service.

    Used for Resources Rules management.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.rule_service_pb2.ListResourceRulesRequest,
        yandex.cloud.cdn.v1.rule_service_pb2.ListResourceRulesResponse,
    ]
    """List all rules for specified resource."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.rule_service_pb2.CreateResourceRuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create new resource rule with specified unique name and rule patter."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.rule_service_pb2.GetResourceRuleRequest,
        yandex.cloud.cdn.v1.rule_pb2.Rule,
    ]
    """Get specified by id resource rule."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.rule_service_pb2.UpdateResourceRuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update specified by id resource rule."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.rule_service_pb2.DeleteResourceRuleRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete specified by id resource rule."""

class ResourceRulesServiceServicer(metaclass=abc.ABCMeta):
    """
    Rules management service.

    Used for Resources Rules management.
    """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.cdn.v1.rule_service_pb2.ListResourceRulesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cdn.v1.rule_service_pb2.ListResourceRulesResponse, collections.abc.Awaitable[yandex.cloud.cdn.v1.rule_service_pb2.ListResourceRulesResponse]]:
        """List all rules for specified resource."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.cdn.v1.rule_service_pb2.CreateResourceRuleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Create new resource rule with specified unique name and rule patter."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.cdn.v1.rule_service_pb2.GetResourceRuleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cdn.v1.rule_pb2.Rule, collections.abc.Awaitable[yandex.cloud.cdn.v1.rule_pb2.Rule]]:
        """Get specified by id resource rule."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.cdn.v1.rule_service_pb2.UpdateResourceRuleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Update specified by id resource rule."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.cdn.v1.rule_service_pb2.DeleteResourceRuleRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete specified by id resource rule."""

def add_ResourceRulesServiceServicer_to_server(servicer: ResourceRulesServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/k8s/v1/cluster.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/k8s/v1/cluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.k8s.v1 import maintenance_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_maintenance__pb2
from yandex.cloud.k8s.v1 import version_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_version__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!yandex/cloud/k8s/v1/cluster.proto\x12\x13yandex.cloud.k8s.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a%yandex/cloud/k8s/v1/maintenance.proto\x1a!yandex/cloud/k8s/v1/version.proto\x1a\x1dyandex/cloud/validation.proto\"\xf4\x08\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x38\n\x06labels\x18\x06 \x03(\x0b\x32(.yandex.cloud.k8s.v1.Cluster.LabelsEntry\x12\x33\n\x06status\x18\x07 \x01(\x0e\x32#.yandex.cloud.k8s.v1.Cluster.Status\x12\x33\n\x06health\x18\x08 \x01(\x0e\x32#.yandex.cloud.k8s.v1.Cluster.Health\x12\x12\n\nnetwork_id\x18\t \x01(\t\x12+\n\x06master\x18\n \x01(\x0b\x32\x1b.yandex.cloud.k8s.v1.Master\x12\x45\n\x14ip_allocation_policy\x18\x0b \x01(\x0b\x32\'.yandex.cloud.k8s.v1.IPAllocationPolicy\x12(\n\x14gateway_ipv4_address\x18\x0c \x01(\tB\x08\x8a\xc8\x31\x04<=15H\x00\x12\x1a\n\x12service_account_id\x18\r \x01(\t\x12\x1f\n\x17node_service_account_id\x18\x0e \x01(\t\x12<\n\x0frelease_channel\x18\x0f \x01(\x0e\x32#.yandex.cloud.k8s.v1.ReleaseChannel\x12:\n\x0enetwork_policy\x18\x10 \x01(\x0b\x32\".yandex.cloud.k8s.v1.NetworkPolicy\x12\x36\n\x0ckms_provider\x18\x11 \x01(\x0b\x32 .yandex.cloud.k8s.v1.KMSProvider\x12\x14\n\x0clog_group_id\x18\x12 \x01(\t\x12-\n\x06\x63ilium\x18\x13 \x01(\x0b\x32\x1b.yandex.cloud.k8s.v1.CiliumH\x01\x12H\n\x15scheduled_maintenance\x18\x14 \x01(\x0b\x32).yandex.cloud.k8s.v1.ScheduledMaintenance\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x87\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0f\n\x0bRECONCILING\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\x0c\n\x08\x44\x45LETING\x10\x06\x12\x0c\n\x08STARTING\x10\x07\"<\n\x06Health\x12\x16\n\x12HEALTH_UNSPECIFIED\x10\x00\x12\x0b\n\x07HEALTHY\x10\x01\x12\r\n\tUNHEALTHY\x10\x02\x42\x12\n\x10internet_gatewayB\x18\n\x16network_implementation\"\xb8\x04\n\x06Master\x12\x38\n\x0czonal_master\x18\x01 \x01(\x0b\x32 .yandex.cloud.k8s.v1.ZonalMasterH\x00\x12>\n\x0fregional_master\x18\x07 \x01(\x0b\x32#.yandex.cloud.k8s.v1.RegionalMasterH\x00\x12\x30\n\tlocations\x18\n \x03(\x0b\x32\x1d.yandex.cloud.k8s.v1.Location\x12\x19\n\x11\x65tcd_cluster_size\x18\x0b \x01(\x03\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x37\n\tendpoints\x18\x03 \x01(\x0b\x32$.yandex.cloud.k8s.v1.MasterEndpoints\x12\x34\n\x0bmaster_auth\x18\x04 \x01(\x0b\x32\x1f.yandex.cloud.k8s.v1.MasterAuth\x12\x36\n\x0cversion_info\x18\x05 \x01(\x0b\x32 .yandex.cloud.k8s.v1.VersionInfo\x12H\n\x12maintenance_policy\x18\x06 \x01(\x0b\x32,.yandex.cloud.k8s.v1.MasterMaintenancePolicy\x12\x1a\n\x12security_group_ids\x18\x08 \x03(\t\x12:\n\x0emaster_logging\x18\t \x01(\x0b\x32\".yandex.cloud.k8s.v1.MasterLoggingB\r\n\x0bmaster_type\",\n\nMasterAuth\x12\x1e\n\x16\x63luster_ca_certificate\x18\x01 \x01(\t\"X\n\x0bZonalMaster\x12\x0f\n\x07zone_id\x18\x01 \x01(\t\x12\x1b\n\x13internal_v4_address\x18\x02 \x01(\t\x12\x1b\n\x13\x65xternal_v4_address\x18\x03 \x01(\t\"z\n\x0eRegionalMaster\x12\x11\n\tregion_id\x18\x01 \x01(\t\x12\x1b\n\x13internal_v4_address\x18\x02 \x01(\t\x12\x1b\n\x13\x65xternal_v4_address\x18\x03 \x01(\t\x12\x1b\n\x13\x65xternal_v6_address\x18\x04 \x01(\t\".\n\x08Location\x12\x0f\n\x07zone_id\x18\x01 \x01(\t\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\"k\n\x0fMasterEndpoints\x12\x1c\n\x14internal_v4_endpoint\x18\x01 \x01(\t\x12\x1c\n\x14\x65xternal_v4_endpoint\x18\x02 \x01(\t\x12\x1c\n\x14\x65xternal_v6_endpoint\x18\x03 \x01(\t\"\xd6\x01\n\x12IPAllocationPolicy\x12\x1f\n\x17\x63luster_ipv4_cidr_block\x18\x01 \x01(\t\x12\x36\n\x18node_ipv4_cidr_mask_size\x18\x05 \x01(\x03\x42\x14\xfa\xc7\x31\x10\x30,24,25,26,27,28\x12\x1f\n\x17service_ipv4_cidr_block\x18\x02 \x01(\t\x12\x1f\n\x17\x63luster_ipv6_cidr_block\x18\x06 \x01(\t\x12\x1f\n\x17service_ipv6_cidr_block\x18\x07 \x01(\tJ\x04\x08\x03\x10\x05\"s\n\x17MasterMaintenancePolicy\x12\x14\n\x0c\x61uto_upgrade\x18\x01 \x01(\x08\x12\x42\n\x12maintenance_window\x18\x02 \x01(\x0b\x32&.yandex.cloud.k8s.v1.MaintenanceWindow\"\x99\x02\n\rMasterLogging\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12;\n\x0clog_group_id\x18\x02 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x12\x38\n\tfolder_id\x18\x03 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x12\x15\n\raudit_enabled\x18\x04 \x01(\x08\x12\"\n\x1a\x63luster_autoscaler_enabled\x18\x05 \x01(\x08\x12\x1e\n\x16kube_apiserver_enabled\x18\x06 \x01(\x08\x12\x16\n\x0e\x65vents_enabled\x18\x07 \x01(\x08\x42\r\n\x0b\x64\x65stination\"\x80\x01\n\rNetworkPolicy\x12=\n\x08provider\x18\x01 \x01(\x0e\x32+.yandex.cloud.k8s.v1.NetworkPolicy.Provider\"0\n\x08Provider\x12\x18\n\x14PROVIDER_UNSPECIFIED\x10\x00\x12\n\n\x06\x43\x41LICO\x10\x01\"\x1d\n\x0bKMSProvider\x12\x0e\n\x06key_id\x18\x01 \x01(\t\"\x80\x01\n\x06\x43ilium\x12=\n\x0crouting_mode\x18\x01 \x01(\x0e\x32\'.yandex.cloud.k8s.v1.Cilium.RoutingMode\"7\n\x0bRoutingMode\x12\x1c\n\x18ROUTING_MODE_UNSPECIFIED\x10\x00\x12\n\n\x06TUNNEL\x10\x01*U\n\x0eReleaseChannel\x12\x1f\n\x1bRELEASE_CHANNEL_UNSPECIFIED\x10\x00\x12\t\n\x05RAPID\x10\x01\x12\x0b\n\x07REGULAR\x10\x02\x12\n\n\x06STABLE\x10\x03\x42V\n\x17yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8sb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.k8s.v1.cluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8s'
  _globals['_CLUSTER_LABELSENTRY']._loaded_options = None
  _globals['_CLUSTER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CLUSTER'].fields_by_name['gateway_ipv4_address']._loaded_options = None
  _globals['_CLUSTER'].fields_by_name['gateway_ipv4_address']._serialized_options = b'\212\3101\004<=15'
  _globals['_IPALLOCATIONPOLICY'].fields_by_name['node_ipv4_cidr_mask_size']._loaded_options = None
  _globals['_IPALLOCATIONPOLICY'].fields_by_name['node_ipv4_cidr_mask_size']._serialized_options = b'\372\3071\0200,24,25,26,27,28'
  _globals['_MASTERLOGGING'].fields_by_name['log_group_id']._loaded_options = None
  _globals['_MASTERLOGGING'].fields_by_name['log_group_id']._serialized_options = b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?'
  _globals['_MASTERLOGGING'].fields_by_name['folder_id']._loaded_options = None
  _globals['_MASTERLOGGING'].fields_by_name['folder_id']._serialized_options = b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?'
  _globals['_RELEASECHANNEL']._serialized_start=3238
  _globals['_RELEASECHANNEL']._serialized_end=3323
  _globals['_CLUSTER']._serialized_start=197
  _globals['_CLUSTER']._serialized_end=1337
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=1046
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=1091
  _globals['_CLUSTER_STATUS']._serialized_start=1094
  _globals['_CLUSTER_STATUS']._serialized_end=1229
  _globals['_CLUSTER_HEALTH']._serialized_start=1231
  _globals['_CLUSTER_HEALTH']._serialized_end=1291
  _globals['_MASTER']._serialized_start=1340
  _globals['_MASTER']._serialized_end=1908
  _globals['_MASTERAUTH']._serialized_start=1910
  _globals['_MASTERAUTH']._serialized_end=1954
  _globals['_ZONALMASTER']._serialized_start=1956
  _globals['_ZONALMASTER']._serialized_end=2044
  _globals['_REGIONALMASTER']._serialized_start=2046
  _globals['_REGIONALMASTER']._serialized_end=2168
  _globals['_LOCATION']._serialized_start=2170
  _globals['_LOCATION']._serialized_end=2216
  _globals['_MASTERENDPOINTS']._serialized_start=2218
  _globals['_MASTERENDPOINTS']._serialized_end=2325
  _globals['_IPALLOCATIONPOLICY']._serialized_start=2328
  _globals['_IPALLOCATIONPOLICY']._serialized_end=2542
  _globals['_MASTERMAINTENANCEPOLICY']._serialized_start=2544
  _globals['_MASTERMAINTENANCEPOLICY']._serialized_end=2659
  _globals['_MASTERLOGGING']._serialized_start=2662
  _globals['_MASTERLOGGING']._serialized_end=2943
  _globals['_NETWORKPOLICY']._serialized_start=2946
  _globals['_NETWORKPOLICY']._serialized_end=3074
  _globals['_NETWORKPOLICY_PROVIDER']._serialized_start=3026
  _globals['_NETWORKPOLICY_PROVIDER']._serialized_end=3074
  _globals['_KMSPROVIDER']._serialized_start=3076
  _globals['_KMSPROVIDER']._serialized_end=3105
  _globals['_CILIUM']._serialized_start=3108
  _globals['_CILIUM']._serialized_end=3236
  _globals['_CILIUM_ROUTINGMODE']._serialized_start=3181
  _globals['_CILIUM_ROUTINGMODE']._serialized_end=3236
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/loadtesting/agent/v1/test_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/loadtesting/agent/v1/test_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.loadtesting.agent.v1 import test_pb2 as yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_test__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/loadtesting/agent/v1/test_service.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a,yandex/cloud/loadtesting/agent/v1/test.proto\"/\n\x0eGetTestRequest\x12\x1d\n\x07test_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x8f\x03\n\x11UpdateTestRequest\x12\x1d\n\x07test_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x10\n\x04name\x18\x03 \x01(\tB\x02\x18\x01\x12\x17\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x02\x18\x01\x12T\n\x06labels\x18\x05 \x03(\x0b\x32@.yandex.cloud.loadtesting.agent.v1.UpdateTestRequest.LabelsEntryB\x02\x18\x01\x12\x14\n\x08\x66\x61vorite\x18\x06 \x01(\x08\x42\x02\x18\x01\x12\x1a\n\x0etarget_version\x18\x07 \x01(\tB\x02\x18\x01\x12\x17\n\x0fimbalance_point\x18\x08 \x01(\x03\x12\x14\n\x0cimbalance_ts\x18\t \x01(\x03\x12\x19\n\x11imbalance_comment\x18\n \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"%\n\x12UpdateTestMetadata\x12\x0f\n\x07test_id\x18\x01 \x01(\t2\xd4\x02\n\x0bTestService\x12\x90\x01\n\x03Get\x12\x31.yandex.cloud.loadtesting.agent.v1.GetTestRequest\x1a\'.yandex.cloud.loadtesting.agent.v1.Test\"-\x82\xd3\xe4\x93\x02\'\x12%/loadtesting/agent/v1/tests/{test_id}\x12\xb1\x01\n\x06Update\x12\x34.yandex.cloud.loadtesting.agent.v1.UpdateTestRequest\x1a!.yandex.cloud.operation.Operation\"N\xb2\xd2*\x1a\n\x12UpdateTestMetadata\x12\x04Test\x82\xd3\xe4\x93\x02*2%/loadtesting/agent/v1/tests/{test_id}:\x01*Bt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.agent.v1.test_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent'
  _globals['_GETTESTREQUEST'].fields_by_name['test_id']._loaded_options = None
  _globals['_GETTESTREQUEST'].fields_by_name['test_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATETESTREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATETESTREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATETESTREQUEST'].fields_by_name['test_id']._loaded_options = None
  _globals['_UPDATETESTREQUEST'].fields_by_name['test_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATETESTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATETESTREQUEST'].fields_by_name['name']._serialized_options = b'\030\001'
  _globals['_UPDATETESTREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATETESTREQUEST'].fields_by_name['description']._serialized_options = b'\030\001'
  _globals['_UPDATETESTREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATETESTREQUEST'].fields_by_name['labels']._serialized_options = b'\030\001'
  _globals['_UPDATETESTREQUEST'].fields_by_name['favorite']._loaded_options = None
  _globals['_UPDATETESTREQUEST'].fields_by_name['favorite']._serialized_options = b'\030\001'
  _globals['_UPDATETESTREQUEST'].fields_by_name['target_version']._loaded_options = None
  _globals['_UPDATETESTREQUEST'].fields_by_name['target_version']._serialized_options = b'\030\001'
  _globals['_TESTSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_TESTSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\'\022%/loadtesting/agent/v1/tests/{test_id}'
  _globals['_TESTSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_TESTSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\032\n\022UpdateTestMetadata\022\004Test\202\323\344\223\002*2%/loadtesting/agent/v1/tests/{test_id}:\001*'
  _globals['_GETTESTREQUEST']._serialized_start=306
  _globals['_GETTESTREQUEST']._serialized_end=353
  _globals['_UPDATETESTREQUEST']._serialized_start=356
  _globals['_UPDATETESTREQUEST']._serialized_end=755
  _globals['_UPDATETESTREQUEST_LABELSENTRY']._serialized_start=710
  _globals['_UPDATETESTREQUEST_LABELSENTRY']._serialized_end=755
  _globals['_UPDATETESTMETADATA']._serialized_start=757
  _globals['_UPDATETESTMETADATA']._serialized_end=794
  _globals['_TESTSERVICE']._serialized_start=797
  _globals['_TESTSERVICE']._serialized_end=1137
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.cdn.v1.origin_group_pb2
import yandex.cloud.cdn.v1.origin_group_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class OriginGroupServiceStub:
    """
    Origin Groups management service.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_group_service_pb2.GetOriginGroupRequest,
        yandex.cloud.cdn.v1.origin_group_pb2.OriginGroup,
    ]
    """Gets origin group with specified origin group id."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_group_service_pb2.ListOriginGroupsRequest,
        yandex.cloud.cdn.v1.origin_group_service_pb2.ListOriginGroupsResponse,
    ]
    """Lists origins of origin group."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_group_service_pb2.CreateOriginGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates origin group."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_group_service_pb2.UpdateOriginGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified origin group.

    Changes may take up to 15 minutes to apply. Afterwards, it is recommended to purge cache of the resources that
    use the origin group via a [CacheService.Purge] request.
    """

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_group_service_pb2.DeleteOriginGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes origin group with specified origin group id."""

class OriginGroupServiceAsyncStub:
    """
    Origin Groups management service.
    """

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_group_service_pb2.GetOriginGroupRequest,
        yandex.cloud.cdn.v1.origin_group_pb2.OriginGroup,
    ]
    """Gets origin group with specified origin group id."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_group_service_pb2.ListOriginGroupsRequest,
        yandex.cloud.cdn.v1.origin_group_service_pb2.ListOriginGroupsResponse,
    ]
    """Lists origins of origin group."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_group_service_pb2.CreateOriginGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates origin group."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_group_service_pb2.UpdateOriginGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified origin group.

    Changes may take up to 15 minutes to apply. Afterwards, it is recommended to purge cache of the resources that
    use the origin group via a [CacheService.Purge] request.
    """

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_group_service_pb2.DeleteOriginGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes origin group with specified origin group id."""

class OriginGroupServiceServicer(metaclass=abc.ABCMeta):
    """
    Origin Groups management service.
    """

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.cdn.v1.origin_group_service_pb2.GetOriginGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cdn.v1.origin_group_pb2.OriginGroup, collections.abc.Awaitable[yandex.cloud.cdn.v1.origin_group_pb2.OriginGroup]]:
        """Gets origin group with specified origin group id."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.cdn.v1.origin_group_service_pb2.ListOriginGroupsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cdn.v1.origin_group_service_pb2.ListOriginGroupsResponse, collections.abc.Awaitable[yandex.cloud.cdn.v1.origin_group_service_pb2.ListOriginGroupsResponse]]:
        """Lists origins of origin group."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.cdn.v1.origin_group_service_pb2.CreateOriginGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates origin group."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.cdn.v1.origin_group_service_pb2.UpdateOriginGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified origin group.

        Changes may take up to 15 minutes to apply. Afterwards, it is recommended to purge cache of the resources that
        use the origin group via a [CacheService.Purge] request.
        """

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.cdn.v1.origin_group_service_pb2.DeleteOriginGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes origin group with specified origin group id."""

def add_OriginGroupServiceServicer_to_server(servicer: OriginGroupServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
